uab.modules.BlizzardFrameGroup = uabFrameGroup:NewModule("Blizzard")
uab.modules.BlizzardFrameGroup.controls = {}
uab.modules.BlizzardFrameGroup.defaultDB = {
    framegroups = {
        ["Player"] = {
            expression = "^PlayerFrame$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "player",
        },
        ["Player Pet"] = {
            expression = "^PetFrame$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "pet",
        },
        ["Party"] = {
            expression = "^PartyMemberFrame.+",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "partyraid",
        },
        ["Target"] = {
            expression = "^TargetFrame$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "target",
        },
        ["Target of Target"] = {
            expression = "^TargetofTargetFrame$",
            usedefaultscale = true,
            usedefaultanchor = true,
            unitgroup = "targettarget",
        },
    },
}

--[[
uab.modules.BlizzardFrameGroup.framesPerUnit.player = 1
uab.modules.BlizzardFrameGroup.framesPerUnit.pet = 1
uab.modules.BlizzardFrameGroup.framesPerUnit.partyraid = 1
uab.modules.BlizzardFrameGroup.framesPerUnit.target = 1
uab.modules.BlizzardFrameGroup.framesPerUnit.targettarget = 1
--]]

function uab.modules.BlizzardFrameGroup:OnInitialize()
    self.super.OnInitialize(self)
end

function uab.modules.BlizzardFrameGroup:OnEnable()
end

function uab.modules.BlizzardFrameGroup:OnDisable()
end

function uab.modules.BlizzardFrameGroup:NewActivator(activator)
	self.controls[activator] = {}
	
    self:AllocateControlsForUnitGroup(activator, "player")
    self:AllocateControlsForUnitGroup(activator, "pet")
    self:AllocateControlsForUnitGroup(activator, "partyraid")
    self:AllocateControlsForUnitGroup(activator, "target")
    self:AllocateControlsForUnitGroup(activator, "targettarget")
end

function uab.modules.BlizzardFrameGroup:AllocateControlsForUnitGroup(activator, groupname)
    self.controls[activator][groupname] = {}
	for idx = 1, uab.constants.groupInfo[groupname].unitcount do
        table.insert(self.controls[activator][groupname], activator:NewUnitGroupControl(groupname))
    end
end

function uab.modules.BlizzardFrameGroup:HaveFrameControl(frame, activator)
	if self.db.profile.disabled then return end

	local options = self:OptionsForFrame(frame)
	
	if not options or options.disabled then return end

	if self.controls[activator] and self.controls[activator][options.unitgroup] then
		return # self.controls[activator][options.unitgroup] > 0
	end
end

function uab.modules.BlizzardFrameGroup:NextFrameControl(frame, activator)
	if self.db.profile.disabled then return end

	local options = self:OptionsForFrame(frame)

	if not options or options.disabled then return end
	
    if self.controls[activator] and self.controls[activator][options.unitgroup]
        and # self.controls[activator][options.unitgroup] > 0 then
		control = table.remove(self.controls[activator][options.unitgroup])
	end

	return control
end

function uab.modules.BlizzardFrameGroup:OptionsForFrame(frame)
    if self.db.profile.disabled then return end
    
    for name, defn in pairs(self.db.profile.framegroups) do
        if self:MatchFrame(frame, defn) then
            return defn
        end
    end
end

function uab.modules.BlizzardFrameGroup:CreateFrameGroupOptions()
    local args = {}

    args = {
        type = 'group',
        name = "Blizzard",
        desc = "Use, anchor, scale, and match expression for the standard Blizzard frames",
        args = {
            enabled = {
                type = 'toggle',
                name = "Enabled",
                desc = "When checked, enable the use of UAB action sets for standard Blizzard frames",
                order = 1,
                get = function()
                    return not self.db.profile.disabled
                end,
                set = function(v)
                    self.db.profile.disabled = not v
                    self.core.core.main:FrameGroupsChanged()
                end,
            },
            
            spacing3 = {
                name = " ",
                type = 'header',
                order = 5,
            },
        },
    }
    
    args.args["player"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player"], "Player", "Blizzard Player")
    args.args["player"].disabled = function() return self.db.profile.disabled end
    args.args["player"].order = 10
    
    args.args["pet"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Player Pet"], "Player Pet", "Blizzard Player Pet")
    args.args["pet"].disabled = function() return self.db.profile.disabled end
    args.args["pet"].order = 20
    
    args.args["party"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Party"], "Party", "Blizzard Party")
    args.args["party"].disabled = function() return self.db.profile.disabled end
    args.args["party"].order = 30
    
    args.args["target"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Target"], "Target", "Blizzard Target")
    args.args["target"].disabled = function() return self.db.profile.disabled end
    args.args["target"].order = 40
    
    args.args["targettarget"] = self:CreateFrameGroupOption(self.db.profile.framegroups["Target of Target"], "Target of Target", "Blizzard Target of Target")
    args.args["targettarget"].disabled = function() return self.db.profile.disabled end
    args.args["targettarget"].order = 50
    
    return args
end

